pygeodesy.triaxials.conformal3.Conformal3

Package pygeodesy :: Package triaxials :: Module conformal3 :: Class Conformal3 |
[frames] | no frames]

# Class Conformal3

          object --+
                   |
        named._Named --+
                       |
        named._NamedBase --+
                           |
        named._NamedEnumItem --+
                               |
    bases._UnOrderedTriaxialBase --+
                                   |
          bases._OrderedTriaxialBase --+
                                       |
                    bases._Triaxial3Base --+
                                           |
                                          Conformal3

Known Subclasses:
  - Conformal3B

Jacobi Conformal projection of triaxial ellipsoid using class Ang lat- and longitudes.

See Also: Triaxial for details.

Instance Methods
equi3Sphere(self, x, y, **name) Get this projection's equivalent Conformal Sphere. |
forwardBetOmg(self, bet, omg, M=False, **unit_name) Compute the projection to this conformal triaxial. |
forwardOther(self, other, bet, omg, M=False, **unit_name) Compute the projection to an other conformal triaxial. |
forwardSphere3(self, bet, omg, M=False, **unit_name) Compute the projection to and direction on the equivalent Conformal Sphere. |
reverseBetOmg(self, x_cf, y=None, M=False, **unit_name) Reverse a projection from this conformal triaxial. |
reverseOther(self, other, beto, omgo, M=False, **unit_name) Reverse a projection from an other conformal triaxial. |
reverseSphere(self, x_ct, y=None, z=None, dir3d=None, M=False, **unit_name) Reverse a projection from this `Conformal Sphere` to this triaxial. |
Inherited from `bases._OrderedTriaxialBase`: `__init__` Inherited from `bases._UnOrderedTriaxialBase`: `areaKT`, `area_p`, `hartzell4`, `height4`, `normal3d`, `normal4`, `sideOf`, `toBiaxial`, `toEllipsoid`, `toStr` Inherited from `named._NamedEnumItem`: `unregister` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others`, `toRepr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| xyQ2 Get the quadrant length in x and y direction (Vector2Tuple{x, y}).
Inherited from `bases._Triaxial3Base`: `Lon0`, `e2`, `isBiaxial`, `isOblate`, `isProlate`, `k2`, `kp2` Inherited from `bases._OrderedTriaxialBase`: `area` Inherited from `bases._UnOrderedTriaxialBase`: `R2`, `R3`, `Rauthalic`, `Rvolumetric`, `a`, `a2`, `abc3`, `areaRG`, `b`, `b2`, `c`, `c2`, `e2ab`, `e2ac`, `e2bc`, `isFlat`, `isOrdered`, `isSpherical`, `perimeter4ab`, `perimeter4ac`, `perimeter4bc`, `unOrdered`, `volume` Inherited from `named._NamedEnumItem`: `name` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### equi3Sphere (self, x, y, **name) |
Get this projection's equivalent Conformal Sphere. Arguments: `x` - Quadrant x length, easting (`meter`). `y` - Quadrant y length, northing (`meter`). Returns: The `Comformal3Sphere` of this projection. See Also: Classes Conformal3Sphere and ConformalSphere and Karney's GeographicLib 2.7 C++ Triaxial::Conformal3 for more information.

### forwardBetOmg (self, bet, omg, M=False, **unit_name) |
Compute the projection to this conformal triaxial. Arguments: `bet` - Ellipsoidal latitude (`Ang` or `unit`). `omg` - Ellipsoidal longitude (`Ang` or `unit`).. `M` - If `True`, compute and include the scale (`bool`). `unit_name` - Optional `unit=`Radians and `name=NN` (`str`). Returns: A Conformal5Tuple`(x, y, z, scale, llk)` with `z = INT0` always and `scale` if `M=True`, otherwise `scale = NAN`.

### forwardOther (self, other, bet, omg, M=False, **unit_name) |
Compute the projection to an other conformal triaxial. Arguments: `other` - A conformal triaxial (`Conformal3`). `bet` - Ellipsoidal latitude (`Ang` or `unit`). `omg` - Ellipsoidal longitude (`Ang` or `unit`). `M` - If `True`, compute and include the scale (`bool`). `unit_name` - Optional `unit=`Radians and `name=NN` (`str`). Returns: A BetOmgGam5Tuple`(bet, omg, gam, scale, llk)` with `scale` if `M=True`, otherwise `scale = NAN`.

### forwardSphere3 (self, bet, omg, M=False, **unit_name) |
Compute the projection to and direction on the equivalent Conformal Sphere. Arguments: `bet` - Ellipsoidal latitude (`Ang` or `unit`). `omg` - Ellipsoidal longitude (`Ang` or `unit`). `M` - If `True`, compute and include the scale (`bool`). `unit_name` - Optional `unit=`Radians and `name=NN` (`str`). Returns: 3-Tuple `(cartesian, direction, scale)` with a `cartesian` Cartesian5Tuple`(x, y, z, h, llk)` on and `direction` a `Vector3d` due North and tangent to the Conformal Sphere and `scale` if `M=True`, otherwise `scale = NAN`.

### reverseBetOmg (self, x_cf, y=None, M=False, **unit_name) |
Reverse a projection from this conformal triaxial. Arguments: `x_cf` - Easting (`scalar`) or a conformal projection (`Conformal5Tuple`). `y` - Northing (`scalar`), required if `x_cf` is `scalar`, ignored otherwise. `M` - If `True`, compute and include the scale (`bool`). `unit_name` - Optional `unit=`Radians and `name=NN` (`str`). Returns: A BetOmgGam5Tuple`(bet, omg, gam, scale, llk)` with `gam` set to `None` and `scale` only if `M=True`, otherwise `scale is NAN`.

### reverseOther (self, other, beto, omgo, M=False, **unit_name) |
Reverse a projection from an other conformal triaxial. Arguments: `other` - A conformal triaxial (`Conformal3`). `beto` - Ellipsoidal latitude on the `other` triaxial (`Ang` or `unit`). `omgo` - Ellipsoidal longitude on the `other` triaxial (`Ang` or `unit`). `M` - If `True`, compute and include the scale (`bool`). `unit_name` - Optional `unit=`Radians and `name=NN` (`str`). Returns: A BetOmgGam5Tuple`(bet, omg, gam, scale, llk)` with `scale` if `M=True`, otherwise `scale = NAN`.

### reverseSphere (self, x_ct, y=None, z=None, dir3d=None, M=False, **unit_name) |
Reverse a projection from this `Conformal Sphere` to this triaxial. Arguments: `x_ct` - X component (`scalar`) of or a cartesian on the `Conformal Sphere` (`Cartesian5Tuple`). `y` - Y component (`scalar`), required if `x_ct` is `scalar`, ignored otherwise. `z` - Z component (`scalar`), like `y`. `dir3d` - The direction (`Vector3d` or `None`), reference. `M` - If `True`, compute and include the scale (`bool`). `unit_name` - Optional `unit=`Radians and `name=NN` (`str`). Returns: A BetOmgGam5Tuple`(bet, omg, gam, scale, llk)` with `scale` only if `M=True`, otherwise `scale = NAN`.

Property Details

### xyQ2 Get the quadrant length in x and y direction (Vector2Tuple{x, y}). Get method: xyQ2(self) - Get the quadrant length in x and y direction (Vector2Tuple{x, y}). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.